#
# spec file for package freetds
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           freetds
Version:        1.4.17
Release:        1.2
Summary:        A free re-implementation of the TDS (Tabular Data Stream) protocol
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
URL:            https://www.freetds.org/
Source:         https://www.freetds.org/files/stable/freetds-%{version}.tar.gz
Source1:        baselibs.conf
Patch0:         configure-return-void-fix.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  unixODBC-devel
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(krb5-gssapi)
BuildRequires:  pkgconfig(nettle)
Requires:       glibc-locale

%description
FreeTDS is a project to document and implement the TDS (Tabular Data Stream)
protocol. TDS is used by Sybase and Microsoft for client to database server
communications. FreeTDS includes call level interfaces for DB-Lib, CT-Lib,
and ODBC.

%package config
Summary:        A free re-implementation of the TDS (Tabular Data Stream) protocol
License:        LGPL-2.1-or-later
Obsoletes:      libfreetds < %{version}
Provides:       %{name} = %{version}
Provides:       libfreetds = %{version}
Obsoletes:      %{name} < %{version}

%description config
FreeTDS is a project to document and implement the TDS (Tabular Data Stream)
protocol. TDS is used by Sybase and Microsoft for client to database server
communications.

This subpackage contains default configuration files and documentation for
them.

%package    tools
Summary:        Applications for working with the TDS (Tabular Data Stream) protocol
License:        GPL-2.0-or-later AND LGPL-2.1-or-later

%description tools
FreeTDS is a project to document and implement the TDS (Tabular Data Stream)
protocol. TDS is used by Sybase and Microsoft for client to database server
communications. FreeTDS includes call level interfaces for DB-Lib, CT-Lib,
and ODBC.

This package provides application to allow users to make use of the protocol.

%package    devel
Summary:        Include files needed for development with FreeTDS
License:        LGPL-2.1-or-later
Requires:       libct4 = %{version}
Requires:       libsybdb5 = %{version}
Requires:       libtdsodbc0 = %{version}

%description devel
The freetds-devel package contains the files necessary for development with
the FreeTDS libraries.

%package -n libct4
Summary:        FreeTDS standalone driver with modern API
License:        LGPL-2.1-or-later

%description -n libct4
ct-lib refers to Sybase's second-generation API, which fixes a number
of implementation and conceptual gaps in db-lib (libsybdb). libct is
not the most complete implementation yet.

%package -n libsybdb5
Summary:        FreeTDS standalone driver with classic API
License:        LGPL-2.1-or-later

%description -n libsybdb5
db-lib is the oldest and simplest API, and the only API supported by
both vendors, which has some relevance when porting applications that
use the vendors' libraries. db-lib was the first API implemented by
FreeTDS, and is still the best one supported. Anything that can be
done in FreeTDS can be done through db-lib.

%package    -n libtdsodbc0
Summary:        FreeTDS ODBC Driver for unixODBC
License:        LGPL-2.1-or-later
Requires:       unixODBC >= 2.0.0

%description -n libtdsodbc0
The ODBC drivers is the FreeTDS's project most recent addition. Its
chief advantage is that it makes FreeTDS servers look like other ODBC
servers, a big help to people who know ODBC and/or write applications
for several kinds of servers.

%package    doc
Summary:        User documentation for FreeTDS
License:        GPL-2.0-or-later AND LGPL-2.1-or-later

%description doc
The freetds-doc package contains the useguide and reference of FreeTDS
and can be installed even if FreeTDS main package is not installed

%prep
%autosetup -p1

%build
%configure \
  --with-unixodbc=%{_prefix} \
  --enable-threadsafe \
  --enable-krb5 \
  --sysconfdir=%{_sysconfdir} \
  --with-tdsver=auto \
  --disable-static \
%if 0%{?suse_version} >= 1310
  --with-gnutls \
%endif
  --with-pic
%make_build RPM_OPT_FLAGS="%{optflags}"

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

# Fix docu location
install -d %{buildroot}%{_docdir}/freetds
mv %{buildroot}%{_datadir}/doc/freetds/* %{buildroot}%{_docdir}/freetds/
rm -rf %{buildroot}%{_docdir}/freetds* %{buildroot}%{_datadir}/doc/freetds-*
# Fix permissions
find %{buildroot}%{_datadir}     -type f -print0 | xargs -0 chmod -x
find %{buildroot}%{_sysconfdir}  -type f -print0 | xargs -0 chmod -x

%fdupes %{buildroot}/%{_prefix}

%post   -n libct4 -p /sbin/ldconfig
%postun -n libct4 -p /sbin/ldconfig
%post   -n libsybdb5 -p /sbin/ldconfig
%postun -n libsybdb5 -p /sbin/ldconfig

%post -n libtdsodbc0
echo "[FreeTDS]
Description = FreeTDS unixODBC Driver
Driver = %{_libdir}/libtdsodbc.so.0
Setup = %{_libdir}/libtdsodbc.so.0" | odbcinst -i -d -r || true
echo "[SQL Server]
Description = FreeTDS unixODBC Driver
Driver = %{_libdir}/libtdsodbc.so.0
Setup = %{_libdir}/libtdsodbc.so.0" | odbcinst -i -d -r || true
/sbin/ldconfig

%postun -n libtdsodbc0 -p /sbin/ldconfig

%preun -n libtdsodbc0
odbcinst -u -d -n 'FreeTDS'
odbcinst -u -d -n 'SQL Server'

%files config
%config %{_sysconfdir}/*
%{_mandir}/man5/*.5%{?ext_man}

%files tools
%{_bindir}/*
%{_mandir}/man1/*.1%{?ext_man}

%files devel
%{_libdir}/*.so
%{_includedir}/*

%files -n libct4
%license COPYING*
%{_libdir}/libct.so.4*

%files -n libsybdb5
%license COPYING*
%{_libdir}/libsybdb.so.5*

%files -n libtdsodbc0
%license COPYING*
%{_libdir}/libtdsodbc.so.*

%files doc
%doc AUTHORS.md NEWS.md README.md TODO.md

%changelog
* Fri Jun  7 2024 Dirk Müller <dmueller@suse.com>
- update to 1.4.17:
  * _blk_get_col_data: Consistently return TDS_FAIL on failure.
  * Support very old Sybase ASE versions
  * datacopy: Increase CREATE TABLE command buffer to accommodate
    larger queries
  * datacopy fails on tables with an unusually high number of
    columns.
  * Change some file license from GPL to LGPL
  * Support Sybase server not configured with UTF-8 charset
* Tue Apr  2 2024 pgajdos@suse.com
- version update to 1.4.12
  * ctlib: Fix crash using ct_command with CS_MORE option
  * defncopy: Use memory instead of temporary file
  * defncopy: Fix MS column length for N(VAR)CHAR types
  * defncopy: Quote strings and identifiers
  * defncopy: Trim spaces around nullable flags
  * defncopy: Fix for order of index recordset
  * defncopy: Quote key index names
  * defncopy: Add test for the applications
- modified patches
  %% configure-return-void-fix.patch (refreshed)
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.10:
  * odbc: Return better error for invalid character set
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.7:
  * tds: improve openssl compatibility
* Thu Nov 16 2023 pgajdos@suse.com
- version update to 1.4.6
  * no upstream changelog found
* Mon Oct  2 2023 pgajdos@suse.com
- version update to 1.4.2
  * User visible (not in a particular order):
  - Fix some numeric conversion checks;
  - Always use Unicode for SSPI allowing not ASCII to work;
  - Improve BCP copy, especially for Sybase;
  - Better error reporting for ICONV failures;
  - Disable TLSv1 by default;
  - ODBC: partial TVP support (missing data at execution);
  - ODBC: support for quoted string in connection string;
  - CT-Library: support large identifiers;
  - CT-Library: report appropriate severity values;
  - apps: datacopy report errors on standard error;
  - pool: use poll instead of select to support more connections.
  * Implementation:
  - Use more bool type for boolean instead of integer;
  - more macros for ODBC tests to encapsulate some ODBC API.
- modified patches
  %% configure-return-void-fix.patch (refreshed)
- have not BUGS.md anymore
* Mon Sep  4 2023 pgajdos@suse.com
- version update to 1.3.20
  * Allows to specify separate date and/or time format.
  * Add "date only format" and "time only format" to locales.conf
    configuration.
  * Better logs for iconv initialization
  * Report more verbose and helpful logs if tds_iconv_init fails.
* Wed Jun  7 2023 pgajdos@suse.com
- version update to 1.3.18
  * Fix redirect with Azure
- modified patches
  %% configure-return-void-fix.patch (refreshed)
* Thu Mar  2 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.17:
  * Update dblib.c - _get_printable_size
  * Added more types to _get_printable_size based on /misc/types.csv
* Thu Dec 22 2022 Dirk Müller <dmueller@suse.com>
- update to 1.3.16:
  * tds_close_socket and tds_connection_close could have been called
    while reading/writing TLS sockets so calling tds_ssl_deinit
    cause some used structure to be released while used.
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 1.3.15:
  * odbc: Fix some issues with SQLCopyDesc
  * Do not change sql_desc_alloc_type copying descriptors.
  * odbc: Return size from SQLGetDescField for integers
* Fri Aug 19 2022 Dirk Müller <dmueller@suse.com>
- update to 1.3.13:
  - Generic:
  - Support UTF-8 columns using MSSQL 2019;
  - Do not accept TDS protocol versions "4.6" (never really supported) and
    "8.0";
  - Minor portability issues;
  - Fix log elision for login;
  - Detect some possible minor memory failure in application;
  - Support long (more than 64k) SSPI packets (never encountered but you
    never know);
  - Fix unicode columns for ASA database;
  - Avoid using BCP with old protocols;
  - (*) Fix bulk copy using big endian machines;
  - (*) Fix Sybase uni(var)char and unsigned types for big endian machines;
  - (*) Do not send nullable data during bulk copy if type is not nullable;
  - ODBC:
  - Added "Timeout" setting;
  - Applications:
  - Improve defncopy utility:
  - Fix some declaration;
  - Fix Sybase support;
  - (*) Fix datacopy and freebcp logging;
  - CT-Library:
  - Minor fix for variant type;
  - Better support for timeout setting;
  - (*) Support some missing types (like nullable unsigned integers) for
    Sybase;
  - DB-library:
  - Unify date format (all systems can use the same syntax);
  - (*) Allows to pass 0 as type for bcp_bind;
  - (*) Fix DBSETLSERVERPRINCIPAL macro;
  - (*) Do not limit queries length for bcp using Sybase;
  - (*) Add KEEP_NULLS to BCP hints.
* Tue May 11 2021 Dirk Müller <dmueller@suse.com>
- remove stale _service and fix Source url
* Sun May  9 2021 brassh@web.de
- update to 1.2.21:
  * minor bug fixes
  * Support some missing types like nullable unsigned smallint
- add baselibs.conf to allow building of i586 libraries (necessary
  to use the driver for programs running under wine)
* Sun Jan 24 2021 Dirk Müller <dmueller@suse.com>
- update to 1.2.18:
- Sybase server:
  - All strings are now converted as MSSQL;
  - Support kerberos login;
  - DB-Library: add DBSETNETWORKAUTH, DBSETMUTUALAUTH, DBSETDELEGATION and
    DBSETSERVERPRINCIPAL;
  - CT-Library: add CS_SEC_NETWORKAUTH, CS_SEC_NETWORKAUTH,
    CS_SEC_NETWORKAUTH and CS_SEC_NETWORKAUTH;
- Bulk copies:
  - DB-Library: fix trim of unicode fields;
  - Apply character conversion for Sybase, like MSSQL;
  - Ignore computed columns;
  - Properly support multibyte strings in column names;
  - DB-Library: stop correctly on BCPMAXERRS setting;
  - DB-Library: do not try to convert skipped rows reading file allowing
    for instance to load CVS files;
- CT-Library: added CS_DATABASE property to allows to connect correctly
  to Azure servers;
- Improve support for MS XML columns for both DB-Library and CT-Library;
- Fix some issues with MSSQL server redirection (used for instance in
  Azure);
- Change SQL_DESC_OCTET_LENGTH value for wise character columns;
- Better support for SQL_VARIANT:
  - Better column checks;
  - CT-Library: now supported, columns are returned as CS_CHAR_TYPE;
- Some updates to server part:
  - Set correctly initial state;
  - IPv6 support;
  - Fix TDS 7.2 logins;
- Support extended character using domain logins under Unix;
- Improve MARS:
  - Less memory copies;
  - Remove possible deadlock;
  - Handle wrapping sequence/window numbers;
  - Make sure we sent the wanted packet;
- Support UTF-16 surrogate pairs in odbc_wide2utf and odbc_set_string_flag
  fixing some character encoding support;
- Fix multiple queries, used by ODBC to optimize data load;
- Improve emulated parameter queries, fixing minor issues and reducing
  memory usage;
- Support DBVERSION_UNKNOWN in dbsetlversion (will use automatic detection);
- CT-Library: define CS_MIN_SYBTYPE and CS_MAX_SYBTYPE;
- CT-Library: fix cs_will_convert accepting library constants, not libTDS.
* Fri May 15 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.36:
  * Various bugfixes
  * bsc#1141132 CVE-2019-13508
* Tue Nov  5 2019 Linnaea Lavia <obs@lavia.moe>
- Enable Kerberos support
- Version update to 1.1.20:
  * Default TDS protocol version is now "auto"
  * Improved UTF-8 performances
  * TDS Pool Server is enabled
  * MARS support is enabled
  * NTLMv2 is enabled
  * See NEWS and ChangeLog for a complete list of changes
* Mon Jul 15 2019 Martin Liška <mliska@suse.cz>
- Add configure-return-void-fix.patch in order to fix wrong
  configure with -Werror=return-type.
* Fri Mar 23 2018 tchvatal@suse.com
- Version update to 1.0.83:
  * See NEWS for a complete list of changes
* Thu May 18 2017 vsistek@suse.com
- Update to version 1.0.39
  * See NEWS for a complete list of changes
* Sat Mar 25 2017 mpluskal@suse.com
- Update to version 1.0.27
  * See NEWS for a complete list of changes
* Thu Jan  5 2017 mpluskal@suse.com
- Update to version 1.00.24
  * See NEWS for a complete list of changes
* Sun May  1 2016 mpluskal@suse.com
- Update to 0.95.95
  * See NEWS for a complete list of changes
* Tue Apr 19 2016 mpluskal@suse.com
- Update to 0.95.94
  * See NEWS for a complete list of changes
* Wed Mar  2 2016 tabraham@suse.com
- Update to 0.95.87
  * See NEWS for a complete list of changes
* Thu Feb 11 2016 mpluskal@suse.com
- Update to 0.95.82
  * See NEWS for complete list of changes
* Sun Jan 17 2016 mpluskal@suse.com
- Update to 0.95.80
  * See NEWS for complete list of changes
* Fri Jan  8 2016 tchvatal@suse.com
- Version update to 0.95.79:
  * See NEWS file for in-depth changes list
* Sun Dec 20 2015 mpluskal@suse.com
- Update to 0.95.76
  - See NEWS for complete list of changes
* Mon Nov 16 2015 mpluskal@suse.com
- Update to 0.95.67
  - See NEWS for complete list of changes
* Sat Oct 31 2015 mpluskal@suse.com
- Update to 0.95.65
  - See NEWS for complete list of changes
- Make building more verbose
* Fri Sep 11 2015 mpluskal@suse.com
- Update to 0.95.8
  - See NEWS for complete list of changes
- Update dependencies
- Enable gnutls support
* Sat Apr 11 2015 tchvatal@suse.com
- Drop autoreconf call which was pointless. Seems to build without
  and thus fixes build on sle11.
* Fri Mar 13 2015 tchvatal@suse.com
- Version bump to 0.91.112:
  * No obvious changelog
- Various spec-cleaner sorting
* Sat Dec  6 2014 jengelh@inai.de
- Update to new upstream release 0.91.103
  * fix memleak when using REALM option in freetds.conf
  * ODBC driver did not return parameters as rows
- freetds-devel had a dangling symlink due to lack of Require on
  libtdsodbc0
- Shlib packaging guideline: put libct and libsybdb in separate
  subpackages.
- Improve description for the different API libraries.
- Do not ignore output from odbcinst or ldconfig.
* Tue Feb  7 2012 coolo@suse.com
- there is a GPL copying too, so add GPL-2.0+ too
* Sun Feb  5 2012 jengelh@medozas.de
- Remove redundant tags/sections
- Resolve dependency indirection
* Wed Oct 12 2011 tabraham@novell.com
- updated to 0.91
* Sun Oct  9 2011 jengelh@medozas.de
- Add missing "Group" for libfreetds and change %%make_install,
  resolving build failure for SLE11
- Remove redundant sections (cf. specfile guidelines)
* Sat Oct  1 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sat Aug  6 2011 toddrme2178@gmail.com
- Split into library and tools (binary) packages
- Fixed license labeling.
* Thu Aug  4 2011 coolo@novell.com
- ran format_spec source service
* Fri Jul 15 2011 toddrme2178@gmail.com
- Updated to 0.91 rc2
- Various spec file style cleanups
- Changed to valid groups (fix for rpmlint warning)
- Check for duplicate files (fix for rpmlint warning)
- Move %%changes contents to existing .changes file
* Fri Jul 15 2011 crrodriguez@opensuse.org
- Update to version 0.9.2
* Thu May 13 2010 Matthias Eckermann <mge@arcor.de>
- update to 0.83.dev.20100512
* Fri Feb 19 2010 Matthias Eckermann <mge@arcor.de>
- update to 0.82.1.dev.20091223
* Thu May  8 2008 Matthias Eckermann <mge@arcor.de>
- adopted for openSUSE buildservice
* Wed Mar 28 2007 Frediano Ziglio <freddy77@gmail.com>
- removed libtdssrv
* Thu Sep  9 2004 Frediano Ziglio <freddy77@angelfire.com>
- remove dependency from freetds-unixodbc
- fix field name (Copyright instead of License)
- updated URL
* Sun Mar 30 2003 Frediano Ziglio <freddy77@angelfire.com>
- add reference to doc package
* Wed Feb  5 2003 Ian Grant <Ian.Grant@cl.cam.ac.uk>
- 0.61 tweaked. Added libtdssrv libraries and tools in /usr/bin + man pages
* Mon Dec 30 2002 David Hollis <dhollis@davehollis.com>
- 0.60 tweaked.  Move .a & .la files to -devel package
* Thu Dec 20 2001 Brian Bruns <camber@ais.org>
- Modifications for 0.53 ver and removing interfaces file
* Thu Jun 28 2001 Brian Bruns <camber@ais.org>
- Modifications for 0.52 ver and ODBC drivers
* Wed Feb 14 2001 David Hollis <dhollis@emagisoft.com>
- First stab at RPM for 0.51 ver
